@@ -1,6 +1,6 @@
-__version__ = "7.2.0"
+__version__ = "7.5.0"
 
 from .arg import AutoName, Expander, Param, Positional
-from .config import Config
+from .config import Config, Validator
 from .errors import Err, Result
 from .types import ParamType
